#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-test
version:              2.13.1.3
visibility:           public
id:                   persistent-test-2.13.1.3-J0ljPvUwHONCmM4oKkjugZ
key:                  persistent-test-2.13.1.3-J0ljPvUwHONCmM4oKkjugZ
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.

category:             Database, Yesod
abi:                  3a4c69a2f8864dddc7acbad5da9e462a
exposed:              True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest ForeignKey
    GeneratedColumnTestSQL HtmlTest Init LargeNumberTest
    LongIdentifierTest MaxLenTest MaybeFieldDefsTest
    MigrationColumnLengthTest MigrationIdempotencyTest
    MigrationOnlyTest MigrationTest MpsCustomPrefixTest MpsNoPrefixTest
    PersistTestPetCollarType PersistTestPetType PersistUniqueTest
    PersistentTest PersistentTestModels PersistentTestModelsImports
    PrimaryTest RawSqlTest ReadWriteTest Recursive RenameTest
    SumTypeTest TransactionLevelTest TreeTest TypeLitFieldDefsTest
    UniqueTest UpsertTest

import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-test
hs-libraries:         HSpersistent-test-2.13.1.3-J0ljPvUwHONCmM4oKkjugZ
depends:
    HUnit-1.6.2.0-AT4Mx0wk6OXAfe1KUqjGNi
    QuickCheck-2.15.0.1-uWFhBSX0xs6KM4Lxmzxul
    aeson-2.2.2.0-vFmFQLvGml64UTioNorrR base-4.18.2.1
    blaze-html-0.9.2.0-3AC4Y0zpDZCFJLvQyYdeIq bytestring-0.11.5.3
    conduit-1.3.6.1-2KVA4kOzD7V4xLYumM6ZM8 containers-0.6.7
    exceptions-0.10.7 hspec-2.11.6-3s90MWARZtIBWQlVSC7vE0
    hspec-expectations-0.8.4-9HP6UZS8rGEGlzbLQDoF6Y
    http-api-data-0.6.1-Ipt6sBrJcTaDxVK63SuHzc
    monad-control-1.0.3.1-CvSzPldK4ciIr3GPTO2wnc
    monad-logger-0.3.42-LdX3XYFZc7y8W4kX5QJ8Zh mtl-2.3.1
    path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    persistent-2.14.5.2-3wZm5oLeWoG8RcdT3jk3aL
    quickcheck-instances-0.3.33-CKrRXSRaGZu8lKYyWkjZIg
    random-1.2.1.3-X9rgjqDoQv2X0ffpw3cKo
    resourcet-1.2.6-culFjMAidR8PUYwviYpcR text-2.0.2 time-1.12.2
    transformers-0.6.1.0
    transformers-base-0.4.6.1-1m5v1p2gPuJ9ksxxBl2y4K
    unliftio-0.2.25.1-AZubcnJ1s2GDDrEwsdsvDw
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-A7v2mkdOMedFLrtoUSJIsH

haddock-interfaces:
    /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock

haddock-html:         /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

